# An Illustrative Python Package

This minimum package is used to show the very basic configurations of packaging a Python project. To be specific, addition and subtraction operations are implemented for illustration.

This project mainly follows the instructions on:
- https://packaging.python.org/tutorials/packaging-projects/
- https://www.freecodecamp.org/news/build-your-first-python-package/

